#!/bin/sh
echo 'name: attoparsec
version: 0.8.6.1
id: attoparsec-0.8.6.1-6571973e9a458e9ceb9b784270798e62

license: BSD3
copyright:
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://bitbucket.org/bos/attoparsec
package-url:
description: A fast parser combinator library, aimed particularly at dealing
             efficiently with network protocols and complicated text/binary
             file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
pkgpath: textproc/hs-attoparsec
exposed: True
exposed-modules: Data.Attoparsec Data.Attoparsec.Char8
                 Data.Attoparsec.Combinator Data.Attoparsec.FastSet
                 Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Types
import-dirs: /usr/local/lib/ghc/attoparsec-0.8.6.1
library-dirs: /usr/local/lib/ghc/attoparsec-0.8.6.1
hs-libraries: HSattoparsec-0.8.6.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
         deepseq-1.1.0.2-0465f803f7d27d264907e7e03e72a71f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-attoparsec-0.8.6.1/html/attoparsec.haddock
haddock-html: /usr/local/share/doc/hs-attoparsec-0.8.6.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
